@@ -2,11 +2,11 @@
 #######################################################################
 """ Special widgets for photosequence adding page
 
-$Id: addimagesequence.py 53291 2009-06-15 00:03:39Z cray $
+$Id: addimagesequence.py 54063 2010-06-30 04:09:18Z corbeau $
 """
 __author__  = u"Andrey Orlov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 53291 $"
+__version__ = "$Revision: 54063 $"
 
 from zope.app.form import CustomWidgetFactory
 from ng.lib.objectwidget import ObjectWidget
@@ -19,6 +19,8 @@ from zope.app.zapi import absoluteURL
 from zope.app.container.interfaces import INameChooser
 
 class AddImageSequence(object) :
+
+
     def getData(self,*kv,**kw) :
         return (('photos',()),('ishidden',False))
         
@@ -28,13 +30,30 @@ class AddImageSequence(object) :
             count += 1
             if not image.data :
                 continue
-                
+
+            print "-0->",dir(image)
+            print "-01->",dir(image.data)
+            print "-02->",type(image.data)
+            print "-1->",dir(self.request.form['field.photos.%u.data' % count])
+            print "-2->",self.request.form['field.photos.%u.data' % count]
+            print "-3->",type(self.request.form['field.photos.%u.data' % count])
+            print "-4->",self.request.form.keys()
+            print "-5->",type(self.request.form['field.photos.%u.data.used' % count])
+            print "-5->",dir(self.request.form['field.photos.%u.data.used' % count])
+            print "-5->",self.request.form['field.photos.%u.data.used' % count]
+            print "-6->",dir(self.request)
+            print self.request
+            print "-7->",self.request.form['field.photos.%u.data' % count]
+                            
             filename = getattr(self.request.form['field.photos.%u.data' % count],"filename",None)
             photo = Photo()
             #photo.__parent__ = self.context
             #photo.__name__ = 'qq'
-            #if image.title :
-            #    filename = unicode(image.title)
+            print "F-->",filename
+            if not filename and image.title :
+                filename = unicode(image.title)
+            print "T-->",filename
+
             self.context[INameChooser(self.context).chooseName(filename,Photo)] = photo
             IDocShort(photo).title = unicode(image.title)
             IDocShort(photo).abstract = unicode(image.abstract)
