@@ -2,15 +2,16 @@
 #######################################################################
 """MixIn class for backreference viewlet.
 
-$Id: viewletbackref.py 52240 2008-12-29 00:25:58Z cray $
+$Id: viewletbackref.py 53378 2009-07-05 20:46:14Z cray $
 """
 __author__  = "Andrey Orlov,2008"
 __license__ = "GPL"
-__version__ = "$Revision: 52240 $"
+__version__ = "$Revision: 53378 $"
 
 from ng.site.content.search.interfaces import ISearch, ISearchName
 from zope.app import zapi 
 import zope.app.catalog.interfaces
+import re
 from ng.lib.viewletbase import ViewletBase
 
 class ViewletBackRef(ViewletBase) :
@@ -26,12 +27,12 @@ class ViewletBackRef(ViewletBase) :
             for item in zapi.getUtility(
                     zope.app.catalog.interfaces.ICatalog,
                     context=self.context). \
-                    searchResults(backkeyword={'any_of':keyword}) :
+                    searchResults(backkeyword={'any_of': [re.sub("\s+"," ",x.lower().strip()) for x in keyword] }) :
                 yield item                    
                     
         for item in zapi.getUtility(
                     zope.app.catalog.interfaces.ICatalog,
                     context=self.context). \
-                    searchResults(backname={'any_of':ISearchName(self.context).name}) :
+                    searchResults(backname={'any_of':ISearch(self.context).name}) :
             yield item
                                 
\ No newline at end of file
