@@ -2,11 +2,11 @@
 #######################################################################
 """MixIn class for content viewlet
 
-$Id: contenticons.py 52321 2009-01-13 13:43:00Z corbeau $
+$Id: contenticons.py 53291 2009-06-15 00:03:39Z cray $
 """
 __author__  = "Andrey Orlov"
 __license__ = "GPL"
-__version__ = "$Revision: 52321 $"
+__version__ = "$Revision: 53291 $"
 
 from ng.lib.viewletbase import ViewletBase
 from ng.content.article.interfaces import IIconContainer
@@ -16,5 +16,4 @@ class ContentIcons(ViewletBase) :
 
     @property
     def images(self) :
-        
-        return IIconContainer(self.context).values()
+        return reversed(IIconContainer(self.context).values())
