@@ -2,11 +2,11 @@
 #######################################################################
 """ErrorView - is base class for zope3 errors
 
-$Id: errorview.py 51952 2008-10-23 20:14:11Z cray $
+$Id: errorview.py 52231 2008-12-27 21:08:17Z cray $
 """
 __author__  = "Andrey Orlov"
 __license__ = "GPL"
-__version__ = "$Revision: 51952 $"
+__version__ = "$Revision: 52231 $"
 
 from zope.publisher.browser import BrowserView
 from zope.app.exception.systemerror import SystemErrorView
@@ -28,6 +28,12 @@ class ErrorView(BrowserView,SystemErrorView):
             IContainer,
             name="Main"),self.request)
 
+    @property
+    def returnurl(self) :
+        url = self.request.form.get('returnurl',self.request.get('HTTP_REFERER',None)) 
+        if url :
+            return url
+        raise KeyError            
 
 class UnauthorizedView(ErrorView):
     """Class for errorpage view"""
