@@ -2,11 +2,11 @@
 #######################################################################
 """MixIn class for searchpage.
 
-$Id: searchpage.py 52739 2009-03-28 14:11:44Z cray $
+$Id: searchpage.py 53378 2009-07-05 20:46:14Z cray $
 """
 __author__  = "Andrey Orlov 2006 12 05"
 __license__ = "GPL"
-__version__ = "$Revision: 52739 $"
+__version__ = "$Revision: 53378 $"
 
 import zope.component
 from zope.app import zapi
@@ -44,7 +44,7 @@ class Search(object) :
 
     @property
     def quotenextkeyword(self) :
-        return quote(self.nextkeyword)
+        return quote(re.sub("\s+"," ",self.nextkeyword.strip()))
     
     @property
     def pager(self) :
@@ -66,7 +66,7 @@ class Search(object) :
         if 'keyword' in d :
             d['keyword']['any_of'] = (re.sub("\s+"," ",d['keyword']['any_of'][0]).strip().lower(),)
         elif 'name' in d :
-            d['name']['any_of'] = (re.sub("\s+"," ",d['name']['any_of'][0]),)            
+            d['name']['any_of'] = (re.sub("\s+"," ",d['name']['any_of'][0].strip()),re.sub("\s+"," ",d['name']['any_of'][0]).lower().strip())            
         elif 'urlpath' in d :            
             path=IPath(self.context).path
             d['urlpath'] = (path,path+u'\xff')
@@ -82,7 +82,6 @@ class Search(object) :
             crosswiki = d['crosswiki']
             del d['crosswiki']
             
-
         res = zapi.getUtility(ICatalog,context=self.context).searchResults(**d)        
         pagersource = ResultSet2PagerSourceAdapter(res)
 
