@@ -2,11 +2,11 @@
 #######################################################################
 """The definitions of a few viewlet provider.
 
-$Id: interfaces.py 52446 2009-02-02 13:41:19Z cray $
+$Id: interfaces.py 54288 2010-09-23 07:20:49Z corbeau $
 """
 __author__  = "Andrey Orlov, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 52446 $"
+__version__ = "$Revision: 54288 $"
 
 from zope.viewlet import interfaces
 from viewletmain.interfaces import INewsListBoxProvider, \
@@ -14,8 +14,12 @@ from viewletmain.interfaces import INewsListBoxProvider, \
 from viewletsubscribe.interfaces import ISubscribeProvider
 from viewletloginbox.interfaces import ILoginBoxProvider
 from viewletrubriclist.interfaces import IRubricListProvider,IRubricCloudProvider,IRubricAllCloudProvider
+from viewlettoolbox.interfaces import IToolBoxProvider
+from viewletgallery.interfaces import IGalleryBoxProvider
 
-class IColumn( 
+class IColumn(
+#    IGalleryBoxProvider,
+    IToolBoxProvider,
     INewsListBoxProvider, 
     ICurrentBoxProvider, 
     ISubscribeProvider,
