@@ -3,11 +3,11 @@
 """Mix-in class for the viewlet display content of parent
 container current object.
 
-$Id: currentbox.py 53268 2009-06-13 06:44:19Z cray $
+$Id: currentbox.py 53642 2009-09-17 13:14:44Z cray $
 """
 __author__  = "Andrey Orlov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 53268 $"
+__version__ = "$Revision: 53642 $"
 
 from zope.app.container.interfaces import  IContainer        
 from zope.app.zapi import getUtility
@@ -30,10 +30,17 @@ class CurrentBox(ViewletBase) :
             raise ValueError
 
         parent = self.context.__parent__
-
         for name in IRegistry(self.context).param("currentbox_disabled_on","").split() + ["Main","news"]:
-            if sameProxiedObjects(parent,getSiteManager(context=self.context).getUtility(IContainer, name)) :
-                raise ValueError
-
+            try :
+                ob = getSiteManager(context=self.context).getUtility(IContainer, name)
+            except LookupError,msg :
+                print "IContainer Utility not found in the CurrentBox viewlet",msg
+                continue
+            else :                                
+                if sameProxiedObjects(parent,ob) :
+                    print "Disable 1"
+                    print name
+                    raise ValueError
+                
         return parent
         
