@@ -3,17 +3,18 @@
 """Base class for a few viewlet display different folderish content
 as menu.
 
-$Id: mainbox.py 52841 2009-04-06 18:01:31Z cray $
+$Id: mainbox.py 54290 2010-09-23 08:20:31Z cray $
 """
 __author__  = "Andrey Orlov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 52841 $"
+__version__ = "$Revision: 54290 $"
 
 from zope.app.container.interfaces import IContainer
 from zope.app.zapi import getSiteManager
 from zope.app.pagetemplate.viewpagetemplatefile import ViewPageTemplateFile
 from ng.lib.viewletbase import ViewletBase
 from ng.app.registry.interfaces import IRegistry
+from ng.content.article.interfaces import IContentContainer
         
 class MainBox(ViewletBase) :
     """ Folder List """
@@ -35,7 +36,7 @@ class MainBox(ViewletBase) :
             return l
 
     def _values(self) :
-        return self.folder.values()
+        return IContentContainer(self.folder).values()
 
     @property
     def folder(self) :
